@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_m_contentWidgetContainer.php 511 2008-04-18 13:29:09Z fishbone $
+ * @version    SVN: $Id: admin_m_contentWidgetContainer.php 736 2008-06-12 01:26:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -26,6 +26,7 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 	const INC_INDEX = 1;		// メニュー項目表示順の増加分
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理ウィジェットのウィジェットID
 	const CONTENT_TYPE = 'mobile';			// コンテンツタイプ
+	const VIEW_CONTENT_TYPE = 'mc';			// 参照数カウント用
 	
 	/**
 	 * コンストラクタ
@@ -311,7 +312,8 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 	function itemListLoop($index, $fetchedRow, $param)
 	{
 		global $gEnvManager;
-
+		global $gAnalyzeManager;
+		
 		$serial = $this->convertToDispString($fetchedRow['cn_serial']);
 		
 		// 表示状態
@@ -324,21 +326,17 @@ class admin_m_contentWidgetContainer extends BaseWidgetContainer
 		if ($fetchedRow['cn_default']){
 			$default = 'checked';
 		}
-		
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
+		// 総参照数
+		$totalViewCount = $gAnalyzeManager->getTotalContentViewCount(self::VIEW_CONTENT_TYPE, $serial);
 		
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
 			'index' => $index,													// 項目番号
 			'serial' => $serial,			// シリアル番号
 			'id' => $this->convertToDispString($fetchedRow['cn_id']),			// ID
 			'name' => $this->convertToDispString($fetchedRow['cn_name']),		// 名前
 			'lang' => $lang,													// 対応言語
 			'link_str' => $this->convertToDispString($fetchedRow['cn_link_url']),		// リンクURL
+			'view_count' => $totalViewCount,									// 総参照数
 			'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['cn_create_dt']),	// 更新日時
 			'visible' => $visible,											// メニュー項目表示制御
